@@ -44,14 +44,18 @@ const std::string SessionImpl::MYSQL_REPEATABLE_READ = "REPEATABLE READ";
 const std::string SessionImpl::MYSQL_SERIALIZABLE = "SERIALIZABLE";
 
 
-SessionImpl::SessionImpl(const std::string& connectionString, std::size_t loginTimeout) : 
+SessionImpl::SessionImpl(const std::string& connectionString, std::size_t loginTimeout) :
 	Poco::Data::AbstractSessionImpl<SessionImpl>(connectionString, loginTimeout),
+	_connector("MySQL"),
 	_handle(0),
 	_connected(false),
-	_inTransaction(false)
+	_inTransaction(false),
+	_failIfInnoReadOnly(false),
+	_lastError(0)
 {
 	addProperty("insertId", &SessionImpl::setInsertId, &SessionImpl::getInsertId);
 	setProperty("handle", static_cast<MYSQL*>(_handle));
+	addFeature("failIfInnoReadOnly", &SessionImpl::setFailIfInnoReadOnly, &SessionImpl::getFailIfInnoReadOnly);
 	open();
 }
 
@@ -70,7 +74,7 @@ void SessionImpl::open(const std::string& connect)
 	poco_assert_dbg (!connectionString().empty());
 
 	_handle.init();
-	
+
 	unsigned int timeout = static_cast<unsigned int>(getLoginTimeout());
 	_handle.options(MYSQL_OPT_CONNECT_TIMEOUT, timeout);
 
@@ -88,7 +92,7 @@ void SessionImpl::open(const std::string& connect)
 	options["character-set"] = "utf8";
 
 	const std::string& connString = connectionString();
-	for (std::string::const_iterator start = connString.begin();;) 
+	for (std::string::const_iterator start = connString.begin();;)
 	{
 		std::string::const_iterator finish = std::find(start, connString.end(), ';');
 		std::string::const_iterator middle = std::find(start, finish, '=');
@@ -101,7 +105,7 @@ void SessionImpl::open(const std::string& connect)
 		if ((finish == connString.end()) || (finish + 1 == connString.end())) break;
 
 		start = finish + 1;
-	} 
+	}
 
 	if (options["user"].empty())
 		throw MySQLException("create session: specify user name");
@@ -128,41 +132,43 @@ void SessionImpl::open(const std::string& connect)
 	else if (!options["auto-reconnect"].empty())
 		throw MySQLException("create session: specify correct auto-reconnect option (true or false) or skip it");
 
+#ifdef MYSQL_SECURE_AUTH
 	if (options["secure-auth"] == "true")
 		_handle.options(MYSQL_SECURE_AUTH, true);
 	else if (options["secure-auth"] == "false")
 		_handle.options(MYSQL_SECURE_AUTH, false);
 	else if (!options["secure-auth"].empty())
 		throw MySQLException("create session: specify correct secure-auth option (true or false) or skip it");
+#endif
 
 	if (!options["character-set"].empty())
 		_handle.options(MYSQL_SET_CHARSET_NAME, options["character-set"].c_str());
 
 	// Real connect
-	_handle.connect(options["host"].c_str(), 
-			options["user"].c_str(), 
-			options["password"].c_str(), 
-			db, 
+	_handle.connect(options["host"].c_str(),
+			options["user"].c_str(),
+			options["password"].c_str(),
+			db,
 			port);
 
-	addFeature("autoCommit", 
-		&SessionImpl::autoCommit, 
+	addFeature("autoCommit",
+		&SessionImpl::autoCommit,
 		&SessionImpl::isAutoCommit);
 
 	_connected = true;
 }
-	
+
 
 SessionImpl::~SessionImpl()
 {
 	close();
 }
-	
 
-Poco::Data::StatementImpl* SessionImpl::createStatementImpl()
+
+Poco::Data::StatementImpl::Ptr SessionImpl::createStatementImpl()
 {
 	return new MySQLStatementImpl(*this);
-}	
+}
 
 
 void SessionImpl::begin()
@@ -182,7 +188,7 @@ void SessionImpl::commit()
 	_handle.commit();
 	_inTransaction = false;
 }
-	
+
 
 void SessionImpl::rollback()
 {
@@ -199,7 +205,7 @@ void SessionImpl::autoCommit(const std::string&, bool val)
 }
 
 
-bool SessionImpl::isAutoCommit(const std::string&)
+bool SessionImpl::isAutoCommit(const std::string&) const
 {
 	int ac = 0;
 	return 1 == getSetting("autocommit", ac);
@@ -229,7 +235,7 @@ void SessionImpl::setTransactionIsolation(Poco::UInt32 ti)
 }
 
 
-Poco::UInt32 SessionImpl::getTransactionIsolation()
+Poco::UInt32 SessionImpl::getTransactionIsolation() const
 {
 	std::string isolation;
 	getSetting("tx_isolation", isolation);
@@ -247,14 +253,65 @@ Poco::UInt32 SessionImpl::getTransactionIsolation()
 }
 
 
-bool SessionImpl::hasTransactionIsolation(Poco::UInt32 ti)
+bool SessionImpl::hasTransactionIsolation(Poco::UInt32 ti) const
 {
 	return Session::TRANSACTION_READ_UNCOMMITTED == ti ||
 		Session::TRANSACTION_READ_COMMITTED == ti ||
 		Session::TRANSACTION_REPEATABLE_READ == ti ||
 		Session::TRANSACTION_SERIALIZABLE == ti;
 }
-	
+
+
+void SessionImpl::reset()
+{
+	if (_connected)
+		_handle.reset();
+}
+
+
+inline bool SessionImpl::isConnected() const
+{
+	return _connected;
+}
+
+
+bool SessionImpl::isGood() const
+{
+	if (_connected)
+	{
+		if (_lastError)
+		{
+			if (_failIfInnoReadOnly)
+			{
+				try
+				{
+					int ro = 0;
+					if (0 == getSetting("innodb_read_only", ro))
+					{
+						_lastError = 0;
+						return true;
+					}
+				}
+				catch (...)
+				{
+				}
+				return false;
+			}
+			else
+			{
+				if (_handle.ping())
+				{
+					_lastError = 0;
+					return true;
+				}
+				return false;
+			}
+		}
+		else return true;
+	}
+	else return false;
+}
+
 
 void SessionImpl::close()
 {
@@ -274,4 +331,4 @@ void SessionImpl::setConnectionTimeout(std::size_t timeout)
 }
 
 
-}}}
+} } } // namespace Poco::Data::MySQL
