@@ -71,7 +71,7 @@ public:
 	Binder(const StatementHandle& rStmt,
 		std::size_t maxFieldSize,
 		ParameterBinding dataBinding = PB_IMMEDIATE,
-		TypeInfo* pDataTypes = 0);
+		const TypeInfo* pDataTypes = 0);
 		/// Creates the Binder.
 
 	~Binder();
@@ -173,7 +173,7 @@ public:
 	void bind(std::size_t pos, const std::list<Poco::UInt64>& val, Direction dir);
 		/// Binds an UInt64 list.
 
-#ifndef POCO_LONG_IS_64_BIT
+#ifndef POCO_INT64_IS_LONG
 	void bind(std::size_t pos, const long& val, Direction dir);
 		/// Binds a long.
 
@@ -1215,7 +1215,7 @@ inline void Binder::bind(std::size_t pos, const std::list<Poco::UInt64>& val, Di
 }
 
 
-#ifndef POCO_LONG_IS_64_BIT
+#ifndef POCO_INT64_IS_LONG
 inline void Binder::bind(std::size_t pos, const long& val, Direction dir)
 {
 	bindImpl(pos, val, SQL_C_SLONG, dir);
