@@ -57,25 +57,25 @@ bool Foundation_API isJSONString(const Var& any);
 
 
 void Foundation_API appendJSONKey(std::string& val, const Var& any);
-	/// Converts the any to a JSON key (i.e. wraps it into double quotes 
+	/// Converts the any to a JSON key (i.e. wraps it into double quotes
 	/// regardless of the underlying type) and appends it to val.
 
 
 void Foundation_API appendJSONString(std::string& val, const Var& any);
-	/// Converts the any to a JSON string (i.e. wraps it into double quotes) 
+	/// Converts the any to a JSON string (i.e. wraps it into double quotes)
 	/// regardless of the underlying type) and appends it to val.
 
 
 void Foundation_API appendJSONValue(std::string& val, const Var& any);
-	/// Converts the any to a JSON value (if underlying type qualifies 
-	/// as string - see isJSONString() - , it is wrapped into double quotes) 
+	/// Converts the any to a JSON value (if underlying type qualifies
+	/// as string - see isJSONString() - , it is wrapped into double quotes)
 	/// and appends it to val
 
 
 template <typename C>
 void containerToJSON(C& cont, std::string& val)
 {
-	// Serialize in JSON format. Note: although this is a vector<T>, the code only 
+	// Serialize in JSON format. Note: although this is a vector<T>, the code only
 	// supports vector<Var>. Total specialization is not possible
 	// because of the cyclic dependency between Var and VarHolder
 
@@ -101,11 +101,11 @@ void containerToJSON(C& cont, std::string& val)
 
 
 class Foundation_API VarHolder
-	/// Interface for a data holder used by the Var class. 
+	/// Interface for a data holder used by the Var class.
 	/// Provides methods to convert between data types.
 	/// Only data types for which VarHolder specialization exists are supported.
-	/// 
-	/// Provided are specializations for all C++ built-in types with addition of 
+	///
+	/// Provided are specializations for all C++ built-in types with addition of
 	/// std::string, Poco::UTF16String, DateTime, LocalDateTime, Timestamp, std::vector<Var> and DynamicStruct.
 	///
 	/// Additional types can be supported by adding specializations. When implementing specializations,
@@ -125,7 +125,7 @@ public:
 	virtual VarHolder* clone(Placeholder<VarHolder>* pHolder = 0) const = 0;
 		/// Implementation must implement this function to
 		/// deep-copy the VarHolder.
-		/// If small object optimization is enabled (i.e. if 
+		/// If small object optimization is enabled (i.e. if
 		/// POCO_NO_SOO is not defined), VarHolder will be
 		/// instantiated in-place if it's size is smaller
 		/// than POCO_SMALL_OBJECT_SIZE.
@@ -178,7 +178,7 @@ public:
 		/// Throws BadCastException. Must be overriden in a type
 		/// specialization in order to support the conversion.
 
-#ifndef POCO_LONG_IS_64_BIT
+#ifndef POCO_INT64_IS_LONG
 
 	void convert(long& val) const;
 		/// Calls convert(Int32).
@@ -241,6 +241,10 @@ public:
 		/// Returns false. Must be properly overriden in a type
 		/// specialization in order to support the diagnostic.
 
+	virtual bool isOrdered() const;
+		/// Returns false. Must be properly overriden in a type
+		/// specialization in order to support the diagnostic.
+
 	virtual bool isInteger() const;
 		/// Returns false. Must be properly overriden in a type
 		/// specialization in order to support the diagnostic.
@@ -284,9 +288,9 @@ protected:
 	VarHolder* cloneHolder(Placeholder<VarHolder>* pVarHolder, const T& val) const
 		/// Instantiates value holder wrapper. If size of the wrapper is
 		/// larger than POCO_SMALL_OBJECT_SIZE, holder is instantiated on
-		/// the heap, otherwise it is instantiated in-place (in the 
+		/// the heap, otherwise it is instantiated in-place (in the
 		/// pre-allocated buffer inside the holder).
-		/// 
+		///
 		/// Called from clone() member function of the implementation when
 		/// small object optimization is enabled.
 	{
@@ -314,7 +318,7 @@ protected:
 	void convertToSmaller(const F& from, T& to) const
 		/// This function is meant to convert signed numeric values from
 		/// larger to smaller type. It checks the upper and lower bound and
-		/// if from value is within limits of type T (i.e. check calls do not throw), 
+		/// if from value is within limits of type T (i.e. check calls do not throw),
 		/// it is converted.
 	{
 		poco_static_assert (std::numeric_limits<F>::is_specialized);
@@ -324,15 +328,15 @@ protected:
 
 		if (std::numeric_limits<F>::is_integer)
 		{
-			checkUpperLimit<F,T>(from); 
+			checkUpperLimit<F,T>(from);
 			checkLowerLimit<F,T>(from);
 		}
 		else
 		{
-			checkUpperLimitFloat<F,T>(from); 
-			checkLowerLimitFloat<F,T>(from); 
+			checkUpperLimitFloat<F,T>(from);
+			checkLowerLimitFloat<F,T>(from);
 		}
-		
+
 		to = static_cast<T>(from);
 	}
 
@@ -349,7 +353,7 @@ protected:
 		poco_static_assert (!std::numeric_limits<F>::is_signed);
 		poco_static_assert (!std::numeric_limits<T>::is_signed);
 
-		checkUpperLimit<F,T>(from); 
+		checkUpperLimit<F,T>(from);
 		to = static_cast<T>(from);
 	}
 
@@ -367,7 +371,7 @@ protected:
 
 		if (from < 0)
 			throw RangeException("Value too small.");
-		checkUpperLimit<F,T>(from); 
+		checkUpperLimit<F,T>(from);
 		to = static_cast<T>(from);
 	}
 
@@ -386,7 +390,7 @@ protected:
 
 		if (from < 0)
 			throw RangeException("Value too small.");
-		checkUpperLimitFloat<F,T>(from); 
+		checkUpperLimitFloat<F,T>(from);
 		to = static_cast<T>(from);
 	}
 
@@ -432,14 +436,14 @@ private:
 	template <typename F, typename T>
 	void checkLowerLimitFloat(const F& from) const
 	{
-		if (from < -std::numeric_limits<T>::max()) 
+		if (from < -std::numeric_limits<T>::max())
 			throw RangeException("Value too small.");
 	}
 
 	template <typename F, typename T>
 	void checkLowerLimit(const F& from) const
 	{
-		if (from < std::numeric_limits<T>::min()) 
+		if (from < std::numeric_limits<T>::min())
 			throw RangeException("Value too small.");
 	}
 };
@@ -515,7 +519,7 @@ inline void VarHolder::convert(Timestamp& /*val*/) const
 	throw BadCastException("Can not convert to Timestamp");
 }
 
-#ifndef POCO_LONG_IS_64_BIT
+#ifndef POCO_INT64_IS_LONG
 
 inline void VarHolder::convert(long& val) const
 {
@@ -612,6 +616,13 @@ inline bool VarHolder::isStruct() const
 	return false;
 }
 
+
+inline bool VarHolder::isOrdered() const
+{
+	return false;
+}
+
+
 inline bool VarHolder::isInteger() const
 {
 	return false;
@@ -659,6 +670,7 @@ inline bool VarHolder::isDateTime() const
 	return false;
 }
 
+
 inline std::size_t VarHolder::size() const
 {
 	return 1u;
@@ -667,7 +679,7 @@ inline std::size_t VarHolder::size() const
 
 template <typename T>
 class VarHolderImpl: public VarHolder
-	/// Template based implementation of a VarHolder. 
+	/// Template based implementation of a VarHolder.
 	/// This class provides type storage for user-defined types
 	/// that do not have VarHolderImpl specialization.
 	///
@@ -730,7 +742,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(Int8);
@@ -745,7 +757,7 @@ public:
 	{
 		val = _val;
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = _val;
@@ -765,7 +777,7 @@ public:
 	{
 		convertSignedToUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertSignedToUnsigned(_val, val);
@@ -776,7 +788,7 @@ public:
 		convertSignedToUnsigned(_val, val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -825,7 +837,7 @@ public:
 	{
 		return cloneHolder(pVarHolder, _val);
 	}
-	
+
 	const Int8& value() const
 	{
 		return _val;
@@ -886,7 +898,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(Int16);
@@ -901,7 +913,7 @@ public:
 	{
 		val = _val;
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = _val;
@@ -921,7 +933,7 @@ public:
 	{
 		convertSignedToUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertSignedToUnsigned(_val, val);
@@ -932,7 +944,7 @@ public:
 		convertSignedToUnsigned(_val, val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -1055,7 +1067,7 @@ public:
 	{
 		convertToSmaller(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = _val;
@@ -1075,7 +1087,7 @@ public:
 	{
 		convertSignedToUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertSignedToUnsigned(_val, val);
@@ -1086,7 +1098,7 @@ public:
 		convertSignedToUnsigned(_val, val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -1207,7 +1219,7 @@ public:
 	{
 		convertToSmaller(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		convertToSmaller(_val, val);
@@ -1227,7 +1239,7 @@ public:
 	{
 		convertSignedToUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertSignedToUnsigned(_val, val);
@@ -1238,7 +1250,7 @@ public:
 		convertSignedToUnsigned(_val, val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -1359,7 +1371,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(UInt8);
@@ -1374,7 +1386,7 @@ public:
 	{
 		convertUnsignedToSigned(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = static_cast<Int32>(_val);
@@ -1394,7 +1406,7 @@ public:
 	{
 		val = _val;
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		val = _val;
@@ -1405,7 +1417,7 @@ public:
 		val = _val;
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -1526,7 +1538,7 @@ public:
 	{
 		convertUnsignedToSigned(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		convertUnsignedToSigned(_val, val);
@@ -1546,7 +1558,7 @@ public:
 	{
 		val = _val;
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		val = _val;
@@ -1557,7 +1569,7 @@ public:
 		val = _val;
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -1678,7 +1690,7 @@ public:
 	{
 		convertUnsignedToSigned(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		convertUnsignedToSigned(_val, val);
@@ -1698,7 +1710,7 @@ public:
 	{
 		convertToSmallerUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		val = _val;
@@ -1709,7 +1721,7 @@ public:
 		val = _val;
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -1830,7 +1842,7 @@ public:
 	{
 		convertUnsignedToSigned(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		convertUnsignedToSigned(_val, val);
@@ -1850,7 +1862,7 @@ public:
 	{
 		convertToSmallerUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertToSmallerUnsigned(_val, val);
@@ -1861,7 +1873,7 @@ public:
 		val = _val;
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -2003,7 +2015,7 @@ public:
 	{
 		val = static_cast<Int16>(_val ? 1 : 0);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = static_cast<Int32>(_val ? 1 : 0);
@@ -2023,7 +2035,7 @@ public:
 	{
 		val = static_cast<UInt16>(_val ? 1 : 0);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		val = static_cast<UInt32>(_val ? 1 : 0);
@@ -2034,7 +2046,7 @@ public:
 		val = static_cast<UInt64>(_val ? 1 : 0);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -2153,7 +2165,7 @@ public:
 	{
 		convertToSmaller(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		convertToSmaller(_val, val);
@@ -2173,7 +2185,7 @@ public:
 	{
 		convertSignedFloatToUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertSignedFloatToUnsigned(_val, val);
@@ -2184,7 +2196,7 @@ public:
 		convertSignedFloatToUnsigned(_val, val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -2200,7 +2212,7 @@ public:
 
 	void convert(bool& val) const
 	{
-		val = !(_val <= std::numeric_limits<float>::min() && 
+		val = !(_val <= std::numeric_limits<float>::min() &&
 			_val >= -1 * std::numeric_limits<float>::min());
 	}
 
@@ -2306,7 +2318,7 @@ public:
 	{
 		convertToSmaller(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		convertToSmaller(_val, val);
@@ -2326,7 +2338,7 @@ public:
 	{
 		convertSignedFloatToUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertSignedFloatToUnsigned(_val, val);
@@ -2337,7 +2349,7 @@ public:
 		convertSignedFloatToUnsigned(_val, val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -2353,7 +2365,7 @@ public:
 
 	void convert(bool& val) const
 	{
-		val = !(_val <= std::numeric_limits<double>::min() && 
+		val = !(_val <= std::numeric_limits<double>::min() &&
 			_val >= -1 * std::numeric_limits<double>::min());
 	}
 
@@ -2465,7 +2477,7 @@ public:
 	{
 		val = static_cast<UInt8>(_val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = static_cast<UInt8>(_val);
@@ -2485,7 +2497,7 @@ public:
 	{
 		val = static_cast<UInt8>(_val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		val = static_cast<UInt8>(_val);
@@ -2496,7 +2508,7 @@ public:
 		val = static_cast<UInt8>(_val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -2621,7 +2633,7 @@ public:
 		int v = NumberParser::parse(_val);
 		convertToSmaller(v, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = NumberParser::parse(_val);
@@ -2643,7 +2655,7 @@ public:
 		unsigned int v = NumberParser::parseUnsigned(_val);
 		convertToSmallerUnsigned(v, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		val = NumberParser::parseUnsigned(_val);
@@ -2654,7 +2666,7 @@ public:
 		val = NumberParser::parseUnsigned64(_val);
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -2846,7 +2858,7 @@ public:
 		val = NumberParser::parseUnsigned64(toStdString());
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -2983,7 +2995,7 @@ private:
 };
 
 
-#ifndef POCO_LONG_IS_64_BIT
+#ifndef POCO_INT64_IS_LONG
 
 
 template <>
@@ -3012,7 +3024,7 @@ public:
 	{
 		convertToSmaller(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		val = static_cast<Int32>(_val);
@@ -3032,7 +3044,7 @@ public:
 	{
 		convertSignedToUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertSignedToUnsigned(_val, val);
@@ -3150,7 +3162,7 @@ public:
 	{
 		convertUnsignedToSigned(_val, val);
 	}
-	
+
 	void convert(Int32& val) const
 	{
 		convertUnsignedToSigned(_val, val);
@@ -3170,7 +3182,7 @@ public:
 	{
 		convertToSmallerUnsigned(_val, val);
 	}
-	
+
 	void convert(UInt32& val) const
 	{
 		convertToSmallerUnsigned(_val, val);
@@ -3262,7 +3274,7 @@ private:
 };
 
 
-#else // if defined (POCO_LONG_IS_64_BIT)
+#else // if defined (POCO_INT64_IS_LONG)
 
 
 template <>
@@ -3561,11 +3573,11 @@ private:
 };
 
 
-#endif // 64bit
+#endif // POCO_INT64_IS_LONG
 
 
 template <typename T>
-class VarHolderImpl<std::vector<T> >: public VarHolder
+class VarHolderImpl<std::vector<T>>: public VarHolder
 {
 public:
 	VarHolderImpl(const std::vector<T>& val): _val(val)
@@ -3575,7 +3587,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(std::vector<T>);
@@ -3590,7 +3602,7 @@ public:
 	{
 		return cloneHolder(pVarHolder, _val);
 	}
-	
+
 	const std::vector<T>& value() const
 	{
 		return _val;
@@ -3630,7 +3642,7 @@ private:
 
 
 template <typename T>
-class VarHolderImpl<std::list<T> >: public VarHolder
+class VarHolderImpl<std::list<T>>: public VarHolder
 {
 public:
 	VarHolderImpl(const std::list<T>& val): _val(val)
@@ -3640,7 +3652,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(std::list<T>);
@@ -3655,7 +3667,7 @@ public:
 	{
 		return cloneHolder(pVarHolder, _val);
 	}
-	
+
 	const std::list<T>& value() const
 	{
 		return _val;
@@ -3705,7 +3717,7 @@ private:
 
 
 template <typename T>
-class VarHolderImpl<std::deque<T> >: public VarHolder
+class VarHolderImpl<std::deque<T>>: public VarHolder
 {
 public:
 	VarHolderImpl(const std::deque<T>& val): _val(val)
@@ -3715,7 +3727,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(std::deque<T>);
@@ -3730,7 +3742,7 @@ public:
 	{
 		return cloneHolder(pVarHolder, _val);
 	}
-	
+
 	const std::deque<T>& value() const
 	{
 		return _val;
@@ -3780,7 +3792,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(DateTime);
@@ -3795,7 +3807,7 @@ public:
 	{
 		throw BadCastException();
 	}
-	
+
 	void convert(Int32& /*val*/) const
 	{
 		throw BadCastException();
@@ -3811,7 +3823,7 @@ public:
 		val = _val.timestamp().epochMicroseconds();
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -3849,7 +3861,7 @@ public:
 	{
 		return cloneHolder(pVarHolder, _val);
 	}
-	
+
 	const DateTime& value() const
 	{
 		return _val;
@@ -3925,7 +3937,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(LocalDateTime);
@@ -3941,7 +3953,7 @@ public:
 		val = _val.timestamp().epochMicroseconds();
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -3979,7 +3991,7 @@ public:
 	{
 		return cloneHolder(pVarHolder, _val);
 	}
-	
+
 	const LocalDateTime& value() const
 	{
 		return _val;
@@ -4055,7 +4067,7 @@ public:
 	~VarHolderImpl()
 	{
 	}
-	
+
 	const std::type_info& type() const
 	{
 		return typeid(Timestamp);
@@ -4071,7 +4083,7 @@ public:
 		val = _val.epochMicroseconds();
 	}
 
-#ifdef POCO_LONG_IS_64_BIT
+#ifdef POCO_INT64_IS_LONG
 
 	void convert(long long& val) const
 	{
@@ -4109,7 +4121,7 @@ public:
 	{
 		return cloneHolder(pVarHolder, _val);
 	}
-	
+
 	const Timestamp& value() const
 	{
 		return _val;
