@@ -37,9 +37,9 @@ ThreadLocalStorage::ThreadLocalStorage()
 
 ThreadLocalStorage::~ThreadLocalStorage()
 {
-	for (TLSMap::iterator it = _map.begin(); it != _map.end(); ++it)
+	for (auto& p: _map)
 	{
-		delete it->second;	
+		delete p.second;	
 	}
 }
 
