@@ -37,28 +37,28 @@ void DateTimeTest::testTimestamp()
 {
 	Timestamp ts(0); // Unix epoch 1970-01-01 00:00:00 Thursday
 	DateTime dt(ts);
-	assert (dt.year() == 1970);
-	assert (dt.month() == 1);
-	assert (dt.day() == 1);
-	assert (dt.hour() == 0);
-	assert (dt.minute() == 0);
-	assert (dt.second() == 0);
-	assert (dt.millisecond() == 0);
-	assert (dt.dayOfWeek() == 4);
-	assert (dt.julianDay() == 2440587.5);
-	assert (dt.timestamp() == 0);
+	assertTrue (dt.year() == 1970);
+	assertTrue (dt.month() == 1);
+	assertTrue (dt.day() == 1);
+	assertTrue (dt.hour() == 0);
+	assertTrue (dt.minute() == 0);
+	assertTrue (dt.second() == 0);
+	assertTrue (dt.millisecond() == 0);
+	assertTrue (dt.dayOfWeek() == 4);
+	assertTrue (dt.julianDay() == 2440587.5);
+	assertTrue (dt.timestamp() == 0);
 
 	ts = Timestamp::fromEpochTime(1000000000);
 	dt = ts; // 2001-09-09 01:46:40 Sunday
-	assert (dt.year() == 2001);
-	assert (dt.month() == 9);
-	assert (dt.day() == 9);
-	assert (dt.hour() == 1);
-	assert (dt.minute() == 46);
-	assert (dt.second() == 40);
-	assert (dt.millisecond() == 0);
-	assert (dt.dayOfWeek() == 0);
-	assert (dt.timestamp().epochTime() == 1000000000);
+	assertTrue (dt.year() == 2001);
+	assertTrue (dt.month() == 9);
+	assertTrue (dt.day() == 9);
+	assertTrue (dt.hour() == 1);
+	assertTrue (dt.minute() == 46);
+	assertTrue (dt.second() == 40);
+	assertTrue (dt.millisecond() == 0);
+	assertTrue (dt.dayOfWeek() == 0);
+	assertTrue (dt.timestamp().epochTime() == 1000000000);
 	assertEqualDelta (dt.julianDay(), 2452161.574074, 0.000001);
 }
 
@@ -66,77 +66,77 @@ void DateTimeTest::testTimestamp()
 void DateTimeTest::testJulian()
 {
 	DateTime dt(2440587.5); // unix epoch as Julian day
-	assert (dt.year() == 1970);
-	assert (dt.month() == 1);
-	assert (dt.day() == 1);
-	assert (dt.hour() == 0);
-	assert (dt.minute() == 0);
-	assert (dt.second() == 0);
-	assert (dt.millisecond() == 0);
-	assert (dt.dayOfWeek() == 4);
-	assert (dt.julianDay() == 2440587.5);
-	assert (dt.timestamp() == 0);
+	assertTrue (dt.year() == 1970);
+	assertTrue (dt.month() == 1);
+	assertTrue (dt.day() == 1);
+	assertTrue (dt.hour() == 0);
+	assertTrue (dt.minute() == 0);
+	assertTrue (dt.second() == 0);
+	assertTrue (dt.millisecond() == 0);
+	assertTrue (dt.dayOfWeek() == 4);
+	assertTrue (dt.julianDay() == 2440587.5);
+	assertTrue (dt.timestamp() == 0);
 	
 	dt = 2299160.5; // 1582-10-15 00:00:00 (first day of Gregorian reform, UTC base)
-	assert (dt.year() == 1582);
-	assert (dt.month() == 10);
-	assert (dt.day() == 15);
-	assert (dt.hour() == 0);
-	assert (dt.minute() == 0);
-	assert (dt.second() == 0);
-	assert (dt.millisecond() == 0);
-	assert (dt.dayOfWeek() == 5);
-	assert (dt.julianDay() == 2299160.5);
+	assertTrue (dt.year() == 1582);
+	assertTrue (dt.month() == 10);
+	assertTrue (dt.day() == 15);
+	assertTrue (dt.hour() == 0);
+	assertTrue (dt.minute() == 0);
+	assertTrue (dt.second() == 0);
+	assertTrue (dt.millisecond() == 0);
+	assertTrue (dt.dayOfWeek() == 5);
+	assertTrue (dt.julianDay() == 2299160.5);
 
 	dt = 0.0; // -4713-11-24 12:00:00 (Gregorian date of Julian day reference)
-	assert (dt.year() == -4713);
-	assert (dt.month() == 11);
-	assert (dt.day() == 24);
-	assert (dt.hour() == 12);
-	assert (dt.minute() == 0);
-	assert (dt.second() == 0);
-	assert (dt.millisecond() == 0);
-	assert (dt.dayOfWeek() == 1);
-	assert (dt.julianDay() == 0);
+	assertTrue (dt.year() == -4713);
+	assertTrue (dt.month() == 11);
+	assertTrue (dt.day() == 24);
+	assertTrue (dt.hour() == 12);
+	assertTrue (dt.minute() == 0);
+	assertTrue (dt.second() == 0);
+	assertTrue (dt.millisecond() == 0);
+	assertTrue (dt.dayOfWeek() == 1);
+	assertTrue (dt.julianDay() == 0);
 
 	// Test that we can represent down to the microsecond.
 	dt = DateTime(2010, 1, 31, 17, 30, 15, 800, 3);
 
-	assert (dt.year() == 2010);
-	assert (dt.month() == 1);
-	assert (dt.day() == 31);
-	assert (dt.hour() == 17);
-	assert (dt.minute() == 30);
-	assert (dt.second() == 15);
-	assert (dt.millisecond() == 800);
-	assert (dt.microsecond() == 3);
+	assertTrue (dt.year() == 2010);
+	assertTrue (dt.month() == 1);
+	assertTrue (dt.day() == 31);
+	assertTrue (dt.hour() == 17);
+	assertTrue (dt.minute() == 30);
+	assertTrue (dt.second() == 15);
+	assertTrue (dt.millisecond() == 800);
+	assertTrue (dt.microsecond() == 3);
 }
 
 
 void DateTimeTest::testGregorian()
 {
 	DateTime dt(1970, 1, 1);
-	assert (dt.year() == 1970);
-	assert (dt.month() == 1);
-	assert (dt.day() == 1);
-	assert (dt.hour() == 0);
-	assert (dt.minute() == 0);
-	assert (dt.second() == 0);
-	assert (dt.millisecond() == 0);
-	assert (dt.dayOfWeek() == 4);
-	assert (dt.julianDay() == 2440587.5);
-	assert (dt.timestamp() == 0);
+	assertTrue (dt.year() == 1970);
+	assertTrue (dt.month() == 1);
+	assertTrue (dt.day() == 1);
+	assertTrue (dt.hour() == 0);
+	assertTrue (dt.minute() == 0);
+	assertTrue (dt.second() == 0);
+	assertTrue (dt.millisecond() == 0);
+	assertTrue (dt.dayOfWeek() == 4);
+	assertTrue (dt.julianDay() == 2440587.5);
+	assertTrue (dt.timestamp() == 0);
 	
 	dt.assign(2001, 9, 9, 1, 46, 40);
-	assert (dt.year() == 2001);
-	assert (dt.month() == 9);
-	assert (dt.day() == 9);
-	assert (dt.hour() == 1);
-	assert (dt.minute() == 46);
-	assert (dt.second() == 40);
-	assert (dt.millisecond() == 0);
-	assert (dt.dayOfWeek() == 0);
-	assert (dt.timestamp().epochTime() == 1000000000);
+	assertTrue (dt.year() == 2001);
+	assertTrue (dt.month() == 9);
+	assertTrue (dt.day() == 9);
+	assertTrue (dt.hour() == 1);
+	assertTrue (dt.minute() == 46);
+	assertTrue (dt.second() == 40);
+	assertTrue (dt.millisecond() == 0);
+	assertTrue (dt.dayOfWeek() == 0);
+	assertTrue (dt.timestamp().epochTime() == 1000000000);
 	assertEqualDelta (dt.julianDay(), 2452161.574074, 0.000001);
 }
 
@@ -153,167 +153,167 @@ void DateTimeTest::testConversions()
 	DateTime dt4(dt2);
 	Timestamp ts4 = dt4.timestamp();
 
-	assert (ts1 == ts2);
-	assert (ts2 == ts3);
-	assert (ts3 == ts4);
+	assertTrue (ts1 == ts2);
+	assertTrue (ts2 == ts3);
+	assertTrue (ts3 == ts4);
 
-	assert (dt2.year() == 2005);
-	assert (dt2.month() == 1);
-	assert (dt2.day() == 28);
-	assert (dt2.hour() == 14);
-	assert (dt2.minute() == 24);
-	assert (dt2.second() == 44);
-	assert (dt2.millisecond() == 234);
-	assert (dt2.dayOfWeek() == 5);
+	assertTrue (dt2.year() == 2005);
+	assertTrue (dt2.month() == 1);
+	assertTrue (dt2.day() == 28);
+	assertTrue (dt2.hour() == 14);
+	assertTrue (dt2.minute() == 24);
+	assertTrue (dt2.second() == 44);
+	assertTrue (dt2.millisecond() == 234);
+	assertTrue (dt2.dayOfWeek() == 5);
 }
 
 
 void DateTimeTest::testStatics()
 {
-	assert (DateTime::isLeapYear(1984));
-	assert (DateTime::isLeapYear(1988));
-	assert (DateTime::isLeapYear(1992));
-	assert (DateTime::isLeapYear(1996));
-	assert (DateTime::isLeapYear(2000));
-	assert (DateTime::isLeapYear(2400));
-	assert (!DateTime::isLeapYear(1995));
-	assert (!DateTime::isLeapYear(1998));
-	assert (!DateTime::isLeapYear(2001));
-	assert (!DateTime::isLeapYear(1800));
-	assert (!DateTime::isLeapYear(1900));
+	assertTrue (DateTime::isLeapYear(1984));
+	assertTrue (DateTime::isLeapYear(1988));
+	assertTrue (DateTime::isLeapYear(1992));
+	assertTrue (DateTime::isLeapYear(1996));
+	assertTrue (DateTime::isLeapYear(2000));
+	assertTrue (DateTime::isLeapYear(2400));
+	assertTrue (!DateTime::isLeapYear(1995));
+	assertTrue (!DateTime::isLeapYear(1998));
+	assertTrue (!DateTime::isLeapYear(2001));
+	assertTrue (!DateTime::isLeapYear(1800));
+	assertTrue (!DateTime::isLeapYear(1900));
 	
-	assert (DateTime::daysOfMonth(2000, 1) == 31);
-	assert (DateTime::daysOfMonth(2000, 2) == 29);
-	assert (DateTime::daysOfMonth(1999, 2) == 28);
+	assertTrue (DateTime::daysOfMonth(2000, 1) == 31);
+	assertTrue (DateTime::daysOfMonth(2000, 2) == 29);
+	assertTrue (DateTime::daysOfMonth(1999, 2) == 28);
 }
 
 
 void DateTimeTest::testCalcs()
 {
 	DateTime dt1(2005, 1, 1);
-	assert (dt1.dayOfYear() == 1);
-	assert (dt1.week(DateTime::MONDAY) == 0);
+	assertTrue (dt1.dayOfYear() == 1);
+	assertTrue (dt1.week(DateTime::MONDAY) == 0);
 	dt1.assign(2005, 1, 3);
-	assert (dt1.dayOfYear() == 3);
-	assert (dt1.week(DateTime::MONDAY) == 1);
+	assertTrue (dt1.dayOfYear() == 3);
+	assertTrue (dt1.week(DateTime::MONDAY) == 1);
 	dt1.assign(2005, 1, 9);
-	assert (dt1.dayOfYear() == 9);
-	assert (dt1.week(DateTime::MONDAY) == 1);
+	assertTrue (dt1.dayOfYear() == 9);
+	assertTrue (dt1.week(DateTime::MONDAY) == 1);
 	dt1.assign(2005, 1, 10);
-	assert (dt1.dayOfYear() == 10);
-	assert (dt1.week(DateTime::MONDAY) == 2);
+	assertTrue (dt1.dayOfYear() == 10);
+	assertTrue (dt1.week(DateTime::MONDAY) == 2);
 	dt1.assign(2005, 2, 1);
-	assert (dt1.dayOfYear() == 32);
-	assert (dt1.week(DateTime::MONDAY) == 5);
+	assertTrue (dt1.dayOfYear() == 32);
+	assertTrue (dt1.week(DateTime::MONDAY) == 5);
 	dt1.assign(2005, 12, 31);
-	assert (dt1.week(DateTime::MONDAY) == 52);
+	assertTrue (dt1.week(DateTime::MONDAY) == 52);
 	dt1.assign(2007, 1, 1);
-	assert (dt1.week(DateTime::MONDAY) == 1);
+	assertTrue (dt1.week(DateTime::MONDAY) == 1);
 	dt1.assign(2007, 12, 31);
-	assert (dt1.week(DateTime::MONDAY) == 53);
+	assertTrue (dt1.week(DateTime::MONDAY) == 53);
 	
 	// Jan 1 is Mon
 	dt1.assign(2001, 1, 1);  
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2001, 1, 7);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2001, 1, 8);
-	assert (dt1.week() == 2);
+	assertTrue (dt1.week() == 2);
 	dt1.assign(2001, 1, 21);
-	assert (dt1.week() == 3);
+	assertTrue (dt1.week() == 3);
 	dt1.assign(2001, 1, 22);
-	assert (dt1.week() == 4);
+	assertTrue (dt1.week() == 4);
 
 	// Jan 1 is Tue
 	dt1.assign(2002, 1, 1);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2002, 1, 6);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2002, 1, 7);
-	assert (dt1.week() == 2);
+	assertTrue (dt1.week() == 2);
 	dt1.assign(2002, 1, 20);
-	assert (dt1.week() == 3);
+	assertTrue (dt1.week() == 3);
 	dt1.assign(2002, 1, 21);
-	assert (dt1.week() == 4);
+	assertTrue (dt1.week() == 4);
 
 	// Jan 1 is Wed
 	dt1.assign(2003, 1, 1);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2003, 1, 5);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2003, 1, 6);
-	assert (dt1.week() == 2);
+	assertTrue (dt1.week() == 2);
 	dt1.assign(2003, 1, 19);
-	assert (dt1.week() == 3);
+	assertTrue (dt1.week() == 3);
 	dt1.assign(2003, 1, 20);
-	assert (dt1.week() == 4);
+	assertTrue (dt1.week() == 4);
 	
 	// Jan 1 is Thu
 	dt1.assign(2004, 1, 1);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2004, 1, 4);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2004, 1, 5);
-	assert (dt1.week() == 2);
+	assertTrue (dt1.week() == 2);
 	dt1.assign(2004, 1, 18);
-	assert (dt1.week() == 3);
+	assertTrue (dt1.week() == 3);
 	dt1.assign(2004, 1, 19);
-	assert (dt1.week() == 4);
+	assertTrue (dt1.week() == 4);
 
 	// Jan 1 is Fri
 	dt1.assign(1999, 1, 1);
-	assert (dt1.week() == 0);
+	assertTrue (dt1.week() == 0);
 	dt1.assign(1999, 1, 3);
-	assert (dt1.week() == 0);
+	assertTrue (dt1.week() == 0);
 	dt1.assign(1999, 1, 4);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(1999, 1, 17);
-	assert (dt1.week() == 2);
+	assertTrue (dt1.week() == 2);
 	dt1.assign(1999, 1, 18);
-	assert (dt1.week() == 3);
+	assertTrue (dt1.week() == 3);
 
 	// Jan 1 is Sat
 	dt1.assign(2000, 1, 1);
-	assert (dt1.week() == 0);
+	assertTrue (dt1.week() == 0);
 	dt1.assign(2000, 1, 2);
-	assert (dt1.week() == 0);
+	assertTrue (dt1.week() == 0);
 	dt1.assign(2000, 1, 3);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(2000, 1, 16);
-	assert (dt1.week() == 2);
+	assertTrue (dt1.week() == 2);
 	dt1.assign(2000, 1, 17);
-	assert (dt1.week() == 3);
+	assertTrue (dt1.week() == 3);
 	
 	// Jan 1 is Sun
 	dt1.assign(1995, 1, 1);
-	assert (dt1.week() == 0);
+	assertTrue (dt1.week() == 0);
 	dt1.assign(1995, 1, 2);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(1995, 1, 3);
-	assert (dt1.week() == 1);
+	assertTrue (dt1.week() == 1);
 	dt1.assign(1995, 1, 15);
-	assert (dt1.week() == 2);
+	assertTrue (dt1.week() == 2);
 	dt1.assign(1995, 1, 16);
-	assert (dt1.week() == 3);
+	assertTrue (dt1.week() == 3);
 }
 
 
 void DateTimeTest::testAMPM()
 {
 	DateTime dt1(2005, 1, 1, 0, 15, 30);
-	assert (dt1.isAM());
-	assert (!dt1.isPM());
-	assert (dt1.hourAMPM() == 12);
+	assertTrue (dt1.isAM());
+	assertTrue (!dt1.isPM());
+	assertTrue (dt1.hourAMPM() == 12);
 	
 	dt1.assign(2005, 1, 1, 12, 15, 30);
-	assert (!dt1.isAM());
-	assert (dt1.isPM());
-	assert (dt1.hourAMPM() == 12);
+	assertTrue (!dt1.isAM());
+	assertTrue (dt1.isPM());
+	assertTrue (dt1.hourAMPM() == 12);
 
 	dt1.assign(2005, 1, 1, 13, 15, 30);
-	assert (!dt1.isAM());
-	assert (dt1.isPM());
-	assert (dt1.hourAMPM() == 1);
+	assertTrue (!dt1.isAM());
+	assertTrue (dt1.isPM());
+	assertTrue (dt1.hourAMPM() == 1);
 }
 
 
@@ -323,19 +323,19 @@ void DateTimeTest::testRelational()
 	DateTime dt2(2005, 1, 2, 0, 15, 30);
 	DateTime dt3(dt1);
 	
-	assert (dt1 < dt2);
-	assert (dt1 <= dt2);
-	assert (dt2 > dt1);
-	assert (dt2 >= dt1);
-	assert (dt1 != dt2);
-	assert (!(dt1 == dt2));
+	assertTrue (dt1 < dt2);
+	assertTrue (dt1 <= dt2);
+	assertTrue (dt2 > dt1);
+	assertTrue (dt2 >= dt1);
+	assertTrue (dt1 != dt2);
+	assertTrue (!(dt1 == dt2));
 	
-	assert (dt1 == dt3);
-	assert (!(dt1 != dt3));
-	assert (dt1 >= dt3);
-	assert (dt1 <= dt3);
-	assert (!(dt1 > dt3));
-	assert (!(dt1 < dt3));
+	assertTrue (dt1 == dt3);
+	assertTrue (!(dt1 != dt3));
+	assertTrue (dt1 >= dt3);
+	assertTrue (dt1 <= dt3);
+	assertTrue (!(dt1 > dt3));
+	assertTrue (!(dt1 < dt3));
 
 	static const struct 
 	{
@@ -372,10 +372,10 @@ void DateTimeTest::testRelational()
 			const DateTime& U = u;
 			u.assign(values[j].year, values[j].month, values[j].day);
 
-			loop_2_assert(i, j, (j <  i) == (U <  V));
-			loop_2_assert(i, j, (j <= i) == (U <= V));
-			loop_2_assert(i, j, (j >= i) == (U >= V));
-			loop_2_assert(i, j, (j >  i) == (U >  V));
+			loop_2_assert (i, j, (j <  i) == (U <  V));
+			loop_2_assert (i, j, (j <= i) == (U <= V));
+			loop_2_assert (i, j, (j >= i) == (U >= V));
+			loop_2_assert (i, j, (j >  i) == (U >  V));
 		}
 	}
 }
@@ -387,15 +387,15 @@ void DateTimeTest::testArithmetics()
 	DateTime dt2(2005, 1, 2, 0, 15, 30);
 	
 	Timespan s = dt2 - dt1;
-	assert (s.days() == 1);
+	assertTrue (s.days() == 1);
 	
 	DateTime dt3 = dt1 + s;
-	assert (dt3 == dt2);
+	assertTrue (dt3 == dt2);
 	
 	dt3 -= s;
-	assert (dt3 == dt1);
+	assertTrue (dt3 == dt1);
 	dt1 += s;
-	assert (dt1 == dt2);
+	assertTrue (dt1 == dt2);
 
 	static const struct 
 	{
@@ -436,32 +436,32 @@ void DateTimeTest::testArithmetics()
 		DateTime x = DateTime(data[di].year1, data[di].month1, data[di].day1);
 		const DateTime& X = x;
 		x += Timespan(num_days, 0, 0, 0, 0);
-		loop_1_assert(line, data[di].year2 == X.year());
-		loop_1_assert(line, data[di].month2 == X.month());
-		loop_1_assert(line, data[di].day2 == X.day());
+		loop_1_assert (line, data[di].year2 == X.year());
+		loop_1_assert (line, data[di].month2 == X.month());
+		loop_1_assert (line, data[di].day2 == X.day());
 	}
 
 	DateTime edgeTime(2014, 9, 16, 0, 0, 0, 0, 10);
 	edgeTime -= Poco::Timespan(11);
-	assert (edgeTime.year() == 2014);
-	assert (edgeTime.month() == 9);
-	assert (edgeTime.day() == 15);
-	assert (edgeTime.hour() == 23);
-	assert (edgeTime.minute() == 59);
-	assert (edgeTime.second() == 59);
-	assert (edgeTime.millisecond() == 999);
-	assert (edgeTime.microsecond() == 999);
+	assertTrue (edgeTime.year() == 2014);
+	assertTrue (edgeTime.month() == 9);
+	assertTrue (edgeTime.day() == 15);
+	assertTrue (edgeTime.hour() == 23);
+	assertTrue (edgeTime.minute() == 59);
+	assertTrue (edgeTime.second() == 59);
+	assertTrue (edgeTime.millisecond() == 999);
+	assertTrue (edgeTime.microsecond() == 999);
 
 	edgeTime.assign(2014, 9, 15, 23, 59, 59, 999, 968);
 	edgeTime += Poco::Timespan(11);
-	assert (edgeTime.year() == 2014);
-	assert (edgeTime.month() == 9);
-	assert (edgeTime.day() == 15);
-	assert (edgeTime.hour() == 23);
-	assert (edgeTime.minute() == 59);
-	assert (edgeTime.second() == 59);
-	assert (edgeTime.millisecond() == 999);
-	assert (edgeTime.microsecond() == 979);
+	assertTrue (edgeTime.year() == 2014);
+	assertTrue (edgeTime.month() == 9);
+	assertTrue (edgeTime.day() == 15);
+	assertTrue (edgeTime.hour() == 23);
+	assertTrue (edgeTime.minute() == 59);
+	assertTrue (edgeTime.second() == 59);
+	assertTrue (edgeTime.millisecond() == 999);
+	assertTrue (edgeTime.microsecond() == 979);
 }
 
 void DateTimeTest::testIncrementDecrement()
@@ -516,13 +516,13 @@ void DateTimeTest::testIncrementDecrement()
 		x = x + Timespan(1,0,0,0,0);  
 		DateTime y = x; const DateTime& Y = y;
 
-		loop_1_assert(line, data[di].year2  == X.year());
-		loop_1_assert(line, data[di].month2 == X.month());
-		loop_1_assert(line, data[di].day2   == X.day());
+		loop_1_assert (line, data[di].year2  == X.year());
+		loop_1_assert (line, data[di].month2 == X.month());
+		loop_1_assert (line, data[di].day2   == X.day());
 
-		loop_1_assert(line, data[di].year2  == Y.year());
-		loop_1_assert(line, data[di].month2 == Y.month());
-		loop_1_assert(line, data[di].day2   == Y.day());
+		loop_1_assert (line, data[di].year2  == Y.year());
+		loop_1_assert (line, data[di].month2 == Y.month());
+		loop_1_assert (line, data[di].day2   == Y.day());
 	}
 
 	for (di = 0; di < num_data; ++di) 
@@ -537,12 +537,12 @@ void DateTimeTest::testIncrementDecrement()
 		const DateTime& X = x;
 		x = x + Timespan(1,0,0,0,0);  
 
-		loop_1_assert(line, data[di].year2  == X.year());
-		loop_1_assert(line, data[di].month2 == X.month());
-		loop_1_assert(line, data[di].day2   == X.day());
-		loop_1_assert(line, data[di].year1  == Y.year());
-		loop_1_assert(line, data[di].month1 == Y.month());
-		loop_1_assert(line, data[di].day1   == Y.day());
+		loop_1_assert (line, data[di].year2  == X.year());
+		loop_1_assert (line, data[di].month2 == X.month());
+		loop_1_assert (line, data[di].day2   == X.day());
+		loop_1_assert (line, data[di].year1  == Y.year());
+		loop_1_assert (line, data[di].month1 == Y.month());
+		loop_1_assert (line, data[di].day1   == Y.day());
 	}
 			
 	for (di = 0; di < num_data; ++di) 
@@ -553,13 +553,13 @@ void DateTimeTest::testIncrementDecrement()
 		x = x - Timespan(1,0,0,0,0);  
 		DateTime y = x; DateTime Y = y;
 
-		loop_1_assert(line, data[di].year1  == X.year());
-		loop_1_assert(line, data[di].month1 == X.month());
-		loop_1_assert(line, data[di].day1   == X.day());
+		loop_1_assert (line, data[di].year1  == X.year());
+		loop_1_assert (line, data[di].month1 == X.month());
+		loop_1_assert (line, data[di].day1   == X.day());
 
-		loop_1_assert(line, data[di].year1  == Y.year());
-		loop_1_assert(line, data[di].month1 == Y.month());
-		loop_1_assert(line, data[di].day1   == Y.day());
+		loop_1_assert (line, data[di].year1  == Y.year());
+		loop_1_assert (line, data[di].month1 == Y.month());
+		loop_1_assert (line, data[di].day1   == Y.day());
 	}
 
 	for (di = 0; di < num_data; ++di) 
@@ -572,13 +572,13 @@ void DateTimeTest::testIncrementDecrement()
 		// would post-decrement x here.
 		x = x - Timespan(1,0,0,0,0);  
 
-		loop_1_assert(line, data[di].year1  == X.year());
-		loop_1_assert(line, data[di].month1 == X.month());
-		loop_1_assert(line, data[di].day1   == X.day());
+		loop_1_assert (line, data[di].year1  == X.year());
+		loop_1_assert (line, data[di].month1 == X.month());
+		loop_1_assert (line, data[di].day1   == X.day());
 
-		loop_1_assert(line, data[di].year2  == Y.year());
-		loop_1_assert(line, data[di].month2 == Y.month());
-		loop_1_assert(line, data[di].day2   == Y.day());
+		loop_1_assert (line, data[di].year2  == Y.year());
+		loop_1_assert (line, data[di].month2 == Y.month());
+		loop_1_assert (line, data[di].day2   == Y.day());
 	}
 }
 
@@ -591,26 +591,26 @@ void DateTimeTest::testSwap()
 	DateTime dt4(2005, 1, 2, 0, 15, 30);
 	
 	dt1.swap(dt2);
-	assert (dt2 == dt3);
-	assert (dt1 == dt4);
+	assertTrue (dt2 == dt3);
+	assertTrue (dt1 == dt4);
 }
 
 
 void DateTimeTest::testUsage()
 {
 	DateTime dt1(1776, 7, 4);
-	assert (dt1.year() == 1776);
-	assert (dt1.month() == 7);
-	assert (dt1.day() == 4);
+	assertTrue (dt1.year() == 1776);
+	assertTrue (dt1.month() == 7);
+	assertTrue (dt1.day() == 4);
 
 	DateTime dt2(dt1);
 	dt2 += Timespan(6, 0, 0, 0, 0);
-	assert (dt2.year() == 1776);
-	assert (dt2.month() == 7);
-	assert (dt2.day() == 10);
+	assertTrue (dt2.year() == 1776);
+	assertTrue (dt2.month() == 7);
+	assertTrue (dt2.day() == 10);
 
 	Timespan span = dt2 - dt1;
-	assert (span.days() == 6);
+	assertTrue (span.days() == 6);
 
 	// TODO - When adding months and years we need to be
 	// able to specify the end-end convention.
@@ -662,8 +662,8 @@ void DateTimeTest::testSetYearDay()
 		// TODO - need to be able to assert with the loop counter
 		// but cppUnit is not able to do this.
 
-		assert (r   == x);
-		assert (day == X.dayOfYear());
+		assertTrue (r   == x);
+		assertTrue (day == X.dayOfYear());
 #endif
 	}
 
@@ -771,7 +771,7 @@ void DateTimeTest::testIsValid()
 		const bool exp   = data[di].d_exp;
 
 		bool isValid = DateTime::isValid(year, month, day);
-		loop_1_assert(line, exp == isValid);
+		loop_1_assert (line, exp == isValid);
 	}
 }
 
@@ -828,7 +828,7 @@ void DateTimeTest::testDayOfWeek()
 		const int line = data[di].d_lineNum;
 		DateTime x = DateTime(data[di].d_year, data[di].d_month, data[di].d_day);
 		const DateTime& X = x;
-		loop_1_assert(line, data[di].d_expDay == X.dayOfWeek());
+		loop_1_assert (line, data[di].d_expDay == X.dayOfWeek());
 	}
 }
 
@@ -837,11 +837,11 @@ void DateTimeTest::testUTC()
 {
 	DateTime dt(2007, 3, 5, 12, 30, 00);
 
-	assert (dt.hour() == 12);
+	assertTrue (dt.hour() == 12);
 	dt.makeUTC(3600);
-	assert (dt.hour() == 11);
+	assertTrue (dt.hour() == 11);
 	dt.makeLocal(3600);
-	assert (dt.hour() == 12);
+	assertTrue (dt.hour() == 12);
 }
 
 
@@ -850,7 +850,24 @@ void DateTimeTest::testLeapSeconds()
 	DateTime dt1(2015, 6, 30, 23, 59, 60);
 	DateTime dt2(2015, 7,  1,  0,  0,  0);
 	
-	assert (dt1 == dt2);
+	assertTrue (dt1 == dt2);
+}
+
+
+void DateTimeTest::testTM()
+{
+	time_t now;
+	time(&now);
+	tm* pTM = gmtime(&now);
+	DateTime dt(*pTM);
+	assertTrue (dt.second() == pTM->tm_sec);
+	assertTrue (dt.minute() == pTM->tm_min);
+	assertTrue (dt.hour() == pTM->tm_hour);
+	assertTrue (dt.day() == pTM->tm_mday);
+	assertTrue (dt.month() == pTM->tm_mon + 1);
+	assertTrue (dt.year() == pTM->tm_year + 1900);
+	assertTrue (dt.dayOfWeek() == pTM->tm_wday);
+	assertTrue (dt.dayOfYear() == pTM->tm_yday + 1);
 }
 
 
@@ -886,6 +903,7 @@ CppUnit::Test* DateTimeTest::suite()
 	CppUnit_addTest(pSuite, DateTimeTest, testIncrementDecrement);
 	CppUnit_addTest(pSuite, DateTimeTest, testUTC);
 	CppUnit_addTest(pSuite, DateTimeTest, testLeapSeconds);
+	CppUnit_addTest(pSuite, DateTimeTest, testTM);
 
 	return pSuite;
 }
