@@ -42,16 +42,16 @@ void ExpireLRUCacheTest::testClear()
 	aCache.add(1, 2);
 	aCache.add(3, 4);
 	aCache.add(5, 6);
-	assert (aCache.has(1));
-	assert (aCache.has(3));
-	assert (aCache.has(5));
-	assert (*aCache.get(1) == 2);
-	assert (*aCache.get(3) == 4);
-	assert (*aCache.get(5) == 6);
+	assertTrue (aCache.has(1));
+	assertTrue (aCache.has(3));
+	assertTrue (aCache.has(5));
+	assertTrue (*aCache.get(1) == 2);
+	assertTrue (*aCache.get(3) == 4);
+	assertTrue (*aCache.get(5) == 6);
 	aCache.clear();
-	assert (!aCache.has(1));
-	assert (!aCache.has(3));
-	assert (!aCache.has(5));
+	assertTrue (!aCache.has(1));
+	assertTrue (!aCache.has(3));
+	assertTrue (!aCache.has(5));
 }
 
 
@@ -74,49 +74,49 @@ void ExpireLRUCacheTest::testExpireN()
 	// 3-1|5 -> 5 gets removed
 	ExpireLRUCache<int, int> aCache(3, DURSLEEP);
 	aCache.add(1, 2); // 1
-	assert (aCache.has(1));
+	assertTrue (aCache.has(1));
 	SharedPtr<int> tmp = aCache.get(1);
-	assert (!tmp.isNull());
-	assert (*tmp == 2);
+	assertTrue (!tmp.isNull());
+	assertTrue (*tmp == 2);
 	Thread::sleep(DURWAIT);
-	assert (!aCache.has(1));
+	assertTrue (!aCache.has(1));
 
 	// tmp must still be valid, access it
-	assert (*tmp == 2);
+	assertTrue (*tmp == 2);
 	tmp = aCache.get(1);
-	assert (!tmp);
+	assertTrue (!tmp);
 
 	aCache.add(1, 2); // 1
 	Thread::sleep(DURHALFSLEEP);
 	aCache.add(3, 4); // 3-1
-	assert (aCache.has(1));
-	assert (aCache.has(3));
+	assertTrue (aCache.has(1));
+	assertTrue (aCache.has(3));
 	tmp = aCache.get(1);
 	SharedPtr<int> tmp2 = aCache.get(3);
-	assert (*tmp == 2);
-	assert (*tmp2 == 4);
+	assertTrue (*tmp == 2); 
+	assertTrue (*tmp2 == 4);
 
 	Thread::sleep(DURHALFSLEEP+25); //3|1
-	assert (!aCache.has(1));
-	assert (aCache.has(3));
-	assert (*tmp == 2); // 1-3
-	assert (*tmp2 == 4); // 3-1
+	assertTrue (!aCache.has(1));
+	assertTrue (aCache.has(3));
+	assertTrue (*tmp == 2); // 1-3
+	assertTrue (*tmp2 == 4); // 3-1
 	tmp2 = aCache.get(3);
-	assert (*tmp2 == 4);
+	assertTrue (*tmp2 == 4);
 	Thread::sleep(DURHALFSLEEP+25); //3|1
-	assert (!aCache.has(3));
-	assert (*tmp2 == 4);
+	assertTrue (!aCache.has(3));
+	assertTrue (*tmp2 == 4);
 	tmp = aCache.get(1);
 	tmp2 = aCache.get(3);
-	assert (!tmp);
-	assert (!tmp2);
+	assertTrue (!tmp);
+	assertTrue (!tmp2);
 
 	// removing illegal entries should work too
 	aCache.remove(666);
 
 	aCache.clear();
-	assert (!aCache.has(5));
-	assert (!aCache.has(3));
+	assertTrue (!aCache.has(5));
+	assertTrue (!aCache.has(3));
 }
 
 
@@ -126,37 +126,37 @@ void ExpireLRUCacheTest::testAccessExpireN()
 	// 3-1|5 -> 5 gets removed
 	AccessExpireLRUCache<int, int> aCache(3, DURSLEEP);
 	aCache.add(1, 2); // 1
-	assert (aCache.has(1));
+	assertTrue (aCache.has(1));
 	SharedPtr<int> tmp = aCache.get(1);
-	assert (!tmp.isNull());
-	assert (*tmp == 2);
-	assert (aCache.size() == 1);
+	assertTrue (!tmp.isNull());
+	assertTrue (*tmp == 2);
+	assertTrue (aCache.size() == 1);
 	Thread::sleep(DURWAIT);
-	assert (aCache.size() == 0);
-	assert (!aCache.has(1));
+	assertTrue (aCache.size() == 0);
+	assertTrue (!aCache.has(1));
 
 	// tmp must still be valid, access it
-	assert (*tmp == 2);
+	assertTrue (*tmp == 2);
 	tmp = aCache.get(1);
-	assert (!tmp);
+	assertTrue (!tmp);
 
 	aCache.add(1, 2); // 1
 	Thread::sleep(DURHALFSLEEP);
 	aCache.add(3, 4); // 3-1
-	assert (aCache.has(1));
-	assert (aCache.has(3));
+	assertTrue (aCache.has(1));
+	assertTrue (aCache.has(3));
 
 	Thread::sleep(DURHALFSLEEP+50); //3|1
-	assert (!aCache.has(1));
-	assert (*aCache.get(3) == 4);
+	assertTrue (!aCache.has(1));
+	assertTrue (*aCache.get(3) == 4);
 	Thread::sleep(DURHALFSLEEP+25); //3|1
-	assert (*aCache.get(3) == 4);
+	assertTrue (*aCache.get(3) == 4);
 	// removing illegal entries should work too
 	aCache.remove(666);
 
 	aCache.clear();
-	assert (!aCache.has(5));
-	assert (!aCache.has(3));
+	assertTrue (!aCache.has(5));
+	assertTrue (!aCache.has(3));
 }
 
 
@@ -178,22 +178,22 @@ void ExpireLRUCacheTest::testCacheSize1()
 {
 	ExpireLRUCache<int, int> aCache(1);
 	aCache.add(1, 2);
-	assert (aCache.has(1));
-	assert (*aCache.get(1) == 2);
+	assertTrue (aCache.has(1));
+	assertTrue (*aCache.get(1) == 2);
 
 	aCache.add(3, 4); // replaces 1
-	assert (!aCache.has(1));
-	assert (aCache.has(3));
-	assert (*aCache.get(3) == 4);
+	assertTrue (!aCache.has(1));
+	assertTrue (aCache.has(3));
+	assertTrue (*aCache.get(3) == 4);
 
 	aCache.add(5, 6);
-	assert (!aCache.has(1));
-	assert (!aCache.has(3));
-	assert (aCache.has(5));
-	assert (*aCache.get(5) == 6);
+	assertTrue (!aCache.has(1));
+	assertTrue (!aCache.has(3));
+	assertTrue (aCache.has(5));
+	assertTrue (*aCache.get(5) == 6);
 
 	aCache.remove(5);
-	assert (!aCache.has(5));
+	assertTrue (!aCache.has(5));
 
 	// removing illegal entries should work too
 	aCache.remove(666);
@@ -206,37 +206,37 @@ void ExpireLRUCacheTest::testCacheSize2()
 	// 3-1|5 -> 5 gets removed
 	ExpireLRUCache<int, int> aCache(2);
 	aCache.add(1, 2); // 1
-	assert (aCache.has(1));
-	assert (*aCache.get(1) == 2);
+	assertTrue (aCache.has(1));
+	assertTrue (*aCache.get(1) == 2);
 
 	aCache.add(3, 4); // 3-1
-	assert (aCache.has(1));
-	assert (aCache.has(3));
-	assert (*aCache.get(1) == 2); // 1-3
-	assert (*aCache.get(3) == 4); // 3-1
+	assertTrue (aCache.has(1));
+	assertTrue (aCache.has(3));
+	assertTrue (*aCache.get(1) == 2); // 1-3
+	assertTrue (*aCache.get(3) == 4); // 3-1
 
 	aCache.add(5, 6); // 5-3|1
-	assert (!aCache.has(1));
-	assert (aCache.has(3));
-	assert (aCache.has(5));
-	assert (*aCache.get(5) == 6);  // 5-3
-	assert (*aCache.get(3) == 4);  // 3-5
+	assertTrue (!aCache.has(1));
+	assertTrue (aCache.has(3));
+	assertTrue (aCache.has(5));
+	assertTrue (*aCache.get(5) == 6);  // 5-3
+	assertTrue (*aCache.get(3) == 4);  // 3-5
 
 	// test remove from the end and the beginning of the list
 	aCache.remove(5); // 3
-	assert (!aCache.has(5));
-	assert (*aCache.get(3) == 4);  // 3
+	assertTrue (!aCache.has(5));
+	assertTrue (*aCache.get(3) == 4);  // 3
 	aCache.add(5, 6); // 5-3
-	assert (*aCache.get(3) == 4);  // 3-5
+	assertTrue (*aCache.get(3) == 4);  // 3-5
 	aCache.remove(3); // 5
-	assert (!aCache.has(3));
-	assert (*aCache.get(5) == 6);  // 5
+	assertTrue (!aCache.has(3));
+	assertTrue (*aCache.get(5) == 6);  // 5
 
 	// removing illegal entries should work too
 	aCache.remove(666);
 
 	aCache.clear();
-	assert (!aCache.has(5));
+	assertTrue (!aCache.has(5));
 }
 
 
@@ -246,48 +246,48 @@ void ExpireLRUCacheTest::testCacheSizeN()
 	// 3-1|5 -> 5 gets removed
 	ExpireLRUCache<int, int> aCache(3);
 	aCache.add(1, 2); // 1
-	assert (aCache.has(1));
-	assert (*aCache.get(1) == 2);
+	assertTrue (aCache.has(1));
+	assertTrue (*aCache.get(1) == 2);
 
 	aCache.add(3, 4); // 3-1
-	assert (aCache.has(1));
-	assert (aCache.has(3));
-	assert (*aCache.get(1) == 2); // 1-3
-	assert (*aCache.get(3) == 4); // 3-1
+	assertTrue (aCache.has(1));
+	assertTrue (aCache.has(3));
+	assertTrue (*aCache.get(1) == 2); // 1-3
+	assertTrue (*aCache.get(3) == 4); // 3-1
 
 	aCache.add(5, 6); // 5-3-1
-	assert (aCache.has(1));
-	assert (aCache.has(3));
-	assert (aCache.has(5));
-	assert (*aCache.get(5) == 6);  // 5-3-1
-	assert (*aCache.get(3) == 4);  // 3-5-1
+	assertTrue (aCache.has(1));
+	assertTrue (aCache.has(3));
+	assertTrue (aCache.has(5));
+	assertTrue (*aCache.get(5) == 6);  // 5-3-1
+	assertTrue (*aCache.get(3) == 4);  // 3-5-1
 
 	aCache.add(7, 8); // 7-5-3|1
-	assert (!aCache.has(1));
-	assert (aCache.has(7));
-	assert (aCache.has(3));
-	assert (aCache.has(5));
-	assert (*aCache.get(5) == 6);  // 5-7-3
-	assert (*aCache.get(3) == 4);  // 3-5-7
-	assert (*aCache.get(7) == 8);  // 7-3-5
+	assertTrue (!aCache.has(1));
+	assertTrue (aCache.has(7));
+	assertTrue (aCache.has(3));
+	assertTrue (aCache.has(5));
+	assertTrue (*aCache.get(5) == 6);  // 5-7-3
+	assertTrue (*aCache.get(3) == 4);  // 3-5-7
+	assertTrue (*aCache.get(7) == 8);  // 7-3-5
 
 	// test remove from the end and the beginning of the list
 	aCache.remove(5); // 7-3
-	assert (!aCache.has(5));
-	assert (*aCache.get(3) == 4);  // 3-7
+	assertTrue (!aCache.has(5));
+	assertTrue (*aCache.get(3) == 4);  // 3-7
 	aCache.add(5, 6); // 5-3-7
-	assert (*aCache.get(7) == 8);  // 7-5-3
+	assertTrue (*aCache.get(7) == 8);  // 7-5-3
 	aCache.remove(7); // 5-3
-	assert (!aCache.has(7));
-	assert (aCache.has(3));
-	assert (*aCache.get(5) == 6);  // 5-3
+	assertTrue (!aCache.has(7));
+	assertTrue (aCache.has(3));
+	assertTrue (*aCache.get(5) == 6);  // 5-3
 
 	// removing illegal entries should work too
 	aCache.remove(666);
 
 	aCache.clear();
-	assert (!aCache.has(5));
-	assert (!aCache.has(3));
+	assertTrue (!aCache.has(5));
+	assertTrue (!aCache.has(3));
 }
 
 
@@ -295,11 +295,11 @@ void ExpireLRUCacheTest::testDuplicateAdd()
 {
 	ExpireLRUCache<int, int> aCache(3);
 	aCache.add(1, 2); // 1
-	assert (aCache.has(1));
-	assert (*aCache.get(1) == 2);
+	assertTrue (aCache.has(1));
+	assertTrue (*aCache.get(1) == 2);
 	aCache.add(1, 3);
-	assert (aCache.has(1));
-	assert (*aCache.get(1) == 3);
+	assertTrue (aCache.has(1));
+	assertTrue (*aCache.get(1) == 3);
 }
 
 
@@ -307,13 +307,13 @@ void ExpireLRUCacheTest::testAccessExpireGet()
 {
 	ExpireLRUCache<int, int> aCache(3, DURSLEEP);
 	aCache.add(1, 2); // 1
-	assert (aCache.has(1));
+	assertTrue (aCache.has(1));
 	SharedPtr<int> tmp = aCache.get(1);
-	assert (!tmp.isNull());
-	assert (*tmp == 2);
+	assertTrue (!tmp.isNull());
+	assertTrue (*tmp == 2);
 	Thread::sleep(DURWAIT);
 	tmp = aCache.get(1);
-	assert (tmp.isNull());
+	assertTrue (tmp.isNull());
 }
 
 
