@@ -50,8 +50,8 @@ void RandomStreamTest::testStream()
 	var /= n;
 	int sd = int(std::sqrt((double) var));
 	
-	assert (110 < avg && avg < 140);
-	assert (sd < 20);
+	assertTrue (110 < avg && avg < 140);
+	assertTrue (sd < 20);
 }
 
 
