@@ -18,6 +18,9 @@
 #define Net_SocketDefs_INCLUDED
 
 
+#include <vector>
+
+
 #define POCO_ENOERR 0
 
 
@@ -25,6 +28,7 @@
 	#include "Poco/UnWindows.h"
 	#include <winsock2.h>
 	#include <ws2tcpip.h>
+	#include <ws2def.h>
 	#define POCO_INVALID_SOCKET  INVALID_SOCKET
 	#define poco_socket_t        SOCKET
 	#define poco_socklen_t       int
@@ -133,6 +137,7 @@
 	#include <sys/types.h>
 	#include <sys/socket.h>
 	#include <sys/un.h>
+	#include <sys/uio.h>
 	#include <fcntl.h>
 	#if POCO_OS != POCO_OS_HPUX
 		#include <sys/select.h>
@@ -351,6 +356,14 @@ namespace Poco {
 namespace Net {
 
 
+#if defined(POCO_OS_FAMILY_WINDOWS)
+	typedef WSABUF SocketBuf;
+#elif defined(POCO_OS_FAMILY_UNIX) // TODO: may need more refinement
+	typedef iovec SocketBuf;
+#endif
+
+typedef std::vector<SocketBuf> SocketBufVec;
+
 struct AddressFamily
 	/// AddressFamily::Family replaces the previously used IPAddress::Family
 	/// enumeration and is now used for IPAddress::Family and SocketAddress::Family.
