@@ -19,6 +19,7 @@
 #include "Poco/Net/HTTPStreamFactory.h"
 #include "Poco/Net/HTTPSStreamFactory.h"
 #include "Poco/Net/FTPStreamFactory.h"
+#include "Poco/Net/FTPSStreamFactory.h"
 #include "Poco/Net/SSLManager.h"
 #include "Poco/Net/KeyConsoleHandler.h"
 #include "Poco/Net/ConsoleCertificateHandler.h"
@@ -35,6 +36,7 @@ using Poco::Exception;
 using Poco::Net::HTTPStreamFactory;
 using Poco::Net::HTTPSStreamFactory;
 using Poco::Net::FTPStreamFactory;
+using Poco::Net::FTPSStreamFactory;
 using Poco::Net::SSLManager;
 using Poco::Net::Context;
 using Poco::Net::KeyConsoleHandler;
@@ -50,7 +52,7 @@ public:
 	{
 		Poco::Net::initializeSSL();
 	}
-	
+
 	~SSLInitializer()
 	{
 		Poco::Net::uninitializeSSL();
@@ -64,7 +66,8 @@ int main(int argc, char** argv)
 	HTTPStreamFactory::registerFactory();
 	HTTPSStreamFactory::registerFactory();
 	FTPStreamFactory::registerFactory();
-	
+	FTPSStreamFactory::registerFactory();
+
 	if (argc != 2)
 	{
 		Path p(argv[0]);
@@ -74,7 +77,7 @@ int main(int argc, char** argv)
 		return 1;
 	}
 
-	// Note: we must create the passphrase handler prior Context 
+	// Note: we must create the passphrase handler prior Context
 	SharedPtr<InvalidCertificateHandler> ptrCert = new ConsoleCertificateHandler(false); // ask the user via console
 	Context::Ptr ptrContext = new Context(Context::CLIENT_USE, "", "", "rootcert.pem", Context::VERIFY_RELAXED, 9, false, "ALL:!ADH:!LOW:!EXP:!MD5:@STRENGTH");
 	SSLManager::instance().initializeClient(0, ptrCert, ptrContext);
@@ -82,11 +85,7 @@ int main(int argc, char** argv)
 	try
 	{
 		URI uri(argv[1]);
-#ifndef POCO_ENABLE_CPP11
-		std::auto_ptr<std::istream> pStr(URIStreamOpener::defaultOpener().open(uri));
-#else
 		std::unique_ptr<std::istream> pStr(URIStreamOpener::defaultOpener().open(uri));
-#endif
 		StreamCopier::copyStream(*pStr.get(), std::cout);
 	}
 	catch (Exception& exc)
@@ -94,6 +93,6 @@ int main(int argc, char** argv)
 		std::cerr << exc.displayText() << std::endl;
 		return 1;
 	}
-		
+
 	return 0;
 }
