@@ -192,11 +192,11 @@ void SecureSocketImpl::connectSSL(bool performHandshake)
 }
 
 
-void SecureSocketImpl::bind(const SocketAddress& address, bool reuseAddress)
+void SecureSocketImpl::bind(const SocketAddress& address, bool reuseAddress, bool reusePort)
 {
 	poco_check_ptr (_pSocket);
 
-	_pSocket->bind(address, reuseAddress);
+	_pSocket->bind(address, reuseAddress, reusePort);
 }
 
 
