@@ -35,7 +35,7 @@ public:
 	~PageReader();
 		/// Destroys the PageReader.
 
-	void parse(std::istream& pageStream);	
+	void parse(std::istream& pageStream);
 		/// Parses a HTML file containing server page directives,
 		/// converts the file into C++ code and adds the code
 		/// to the reader's Page object. Also parses page
@@ -53,6 +53,7 @@ protected:
 		STATE_PREHANDLER,
 		STATE_BLOCK,
 		STATE_EXPR,
+		STATE_ESC_EXPR,
 		STATE_COMMENT,
 		STATE_ATTR
 	};
@@ -61,16 +62,19 @@ protected:
 	static const std::string MARKUP_END;
 	static const std::string EXPR_BEGIN;
 	static const std::string EXPR_END;
+	static const std::string ESC_EXPR_BEGIN;
+	static const std::string ESC_EXPR_END;
 
 	void include(const std::string& path);
 	void parseAttributes();
 	void nextToken(std::istream& istr, std::string& token);
 	void handleAttribute(const std::string& name, const std::string& value);
 	std::string where() const;
+	bool escape() const;
 
 protected:
 	void generateLineDirective(std::ostream& ostr);
-	
+
 private:
 	PageReader();
 	PageReader(const PageReader&);
@@ -80,7 +84,7 @@ private:
 	const PageReader* _pParent;
 	std::string _path;
 	std::string _attrs;
-	int _line;
+	std::streamsize _line;
 	bool _emitLineDirectives;
 };
 
