@@ -46,20 +46,20 @@ void SystemConfigurationTest::testProperties()
 {
 	AutoPtr<SystemConfiguration> pConf = new SystemConfiguration;
 	
-	assert (pConf->getString("system.osName") == Environment::osName());
-	assert (pConf->getString("system.osVersion") == Environment::osVersion());
-	assert (pConf->getString("system.osArchitecture") == Environment::osArchitecture());
-	assert (pConf->getString("system.nodeName") == Environment::nodeName());
-	assert (pConf->getString("system.currentDir") == Path::current());
-	assert (pConf->getString("system.homeDir") == Path::home());
-	assert (pConf->getString("system.tempDir") == Path::temp());
+	assertTrue (pConf->getString("system.osName") == Environment::osName());
+	assertTrue (pConf->getString("system.osVersion") == Environment::osVersion());
+	assertTrue (pConf->getString("system.osArchitecture") == Environment::osArchitecture());
+	assertTrue (pConf->getString("system.nodeName") == Environment::nodeName());
+	assertTrue (pConf->getString("system.currentDir") == Path::current());
+	assertTrue (pConf->getString("system.homeDir") == Path::home());
+	assertTrue (pConf->getString("system.tempDir") == Path::temp());
 	
 	std::string dateTime = pConf->getString("system.dateTime");
-	assert (dateTime.size() == 20);
+	assertTrue (dateTime.size() == 20);
 	
 #if !defined(POCO_VXWORKS)
 	std::string pid = pConf->getString("system.pid");
-	assert (Poco::NumberParser::parse64(pid) == Poco::Process::id());
+	assertTrue (Poco::NumberParser::parse64(pid) == Poco::Process::id());
 #endif
 	
 #if defined(POCO_OS_FAMILY_WINDOWS)
@@ -67,7 +67,7 @@ void SystemConfigurationTest::testProperties()
 #else
 	std::string home = pConf->getString("system.env.HOME");
 #endif
-	assert (!home.empty());
+	assertTrue (!home.empty());
 }
 
 
@@ -77,31 +77,31 @@ void SystemConfigurationTest::testKeys()
 
 	AbstractConfiguration::Keys keys;
 	pConf->keys(keys);
-	assert (keys.size() == 1);
-	assert (std::find(keys.begin(), keys.end(), "system") != keys.end());
+	assertTrue (keys.size() == 1);
+	assertTrue (std::find(keys.begin(), keys.end(), "system") != keys.end());
 
 	pConf->keys("system", keys);
 #if defined(POCO_VXWORKS)
-	assert (keys.size() == 10);
+	assertTrue (keys.size() == 10);
 #else
-	assert (keys.size() == 16);
+	assertTrue (keys.size() == 16);
 #endif
-	assert (std::find(keys.begin(), keys.end(), "osName") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "osVersion") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "osArchitecture") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "nodeName") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "nodeId") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "currentDir") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "homeDir") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "configHomeDir") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "cacheHomeDir") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "dataHomeDir") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "tempDir") != keys.end());
-	assert (std::find(keys.begin(), keys.end(), "dateTime") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "osName") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "osVersion") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "osArchitecture") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "nodeName") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "nodeId") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "currentDir") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "homeDir") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "configHomeDir") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "cacheHomeDir") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "dataHomeDir") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "tempDir") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "dateTime") != keys.end());
 #if !defined(POCO_VXWORKS)
-	assert (std::find(keys.begin(), keys.end(), "pid") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "pid") != keys.end());
 #endif
-	assert (std::find(keys.begin(), keys.end(), "env") != keys.end());
+	assertTrue (std::find(keys.begin(), keys.end(), "env") != keys.end());
 }
 
 
