@@ -32,10 +32,10 @@ std::string fromXMLString(const XMLString& str)
 	std::string result;
 	result.reserve(str.size());
 	
-	for (XMLString::const_iterator it = str.begin(); it != str.end(); ++it)
+	for (auto xc: str)
 	{
 		char c;
-		wctomb(&c, *it);
+		wctomb(&c, xc);
 		result += c;
 	}
 	return result;
